#
# spec file for package perl-Mouse
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Mouse
Name:           perl-Mouse
Version:        2.5.11
Release:        1.1
# v2.5.11 -> normalize -> 2.5.11
%define cpan_version v2.5.11
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Moose minus the antlers
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/S/SK/SKAJI/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Devel::PPPort) >= 3.59
BuildRequires:  perl(ExtUtils::ParseXS) >= 3.22
BuildRequires:  perl(Module::Build) >= 0.4005
BuildRequires:  perl(Module::Build::XSUtil) >= 0.19
BuildRequires:  perl(Test::Exception)
BuildRequires:  perl(Test::Fatal)
BuildRequires:  perl(Test::LeakTrace)
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Test::Output)
BuildRequires:  perl(Test::Requires)
BuildRequires:  perl(Try::Tiny)
BuildRequires:  perl(version) >= 0.9913
%{perl_requires}

%description
Moose is a postmodern object system for Perl5. Moose is wonderful.

Unfortunately, Moose has a compile-time penalty. Though significant
progress has been made over the years, the compile time penalty is a
non-starter for some very specific applications. If you are writing a
command-line application or CGI script where startup time is essential, you
may not be able to use Moose (we recommend that you instead use persistent
Perl executing environments like 'FastCGI' for the latter, if possible).

Mouse is a Moose compatible object system, which aims to alleviate this
penalty by providing a subset of Moose's functionality.

We're also going as light on dependencies as possible. Mouse currently has
*no dependencies* except for building/testing modules. Mouse also works
without XS, although it has an XS backend to make it much faster.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Build.PL --installdirs=vendor optimize="%{optflags}"
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes example README.md
%license LICENSE

%changelog
* Mon Aug  5 2024 Tina Müller <timueller+perl@suse.de>
- updated to 2.5.11 (v2.5.11)
  see /usr/share/doc/packages/perl-Mouse/Changes
  v2.5.11 2024-08-04T11:38:02Z
  - Use Devel-PPPort 3.59 (atoomic #113)
  - Mark "builtin" as foreign (#123)
* Sun Mar 29 2020 <timueller+perl@suse.de>
- updated to 2.5.10
  see /usr/share/doc/packages/perl-Mouse/Changes
  v2.5.10 2020-03-28T13:15:57Z
  - Do not use Fatal (#108)
* Tue Aug 27 2019 Stephan Kulow <coolo@suse.com>
- updated to 2.5.9
  see /usr/share/doc/packages/perl-Mouse/Changes
  v2.5.9 2019-08-26T14:46:49Z
  - Fix circular dependencies between Mouse and MouseX::Foreign (pghmcfc #102)
* Mon Aug 26 2019 Stephan Kulow <coolo@suse.com>
- updated to 2.5.8
  see /usr/share/doc/packages/perl-Mouse/Changes
  v2.5.8 2019-08-25T18:52:19Z
  - Fix segmentation fault which occurs when using MouseX::Foreign and role->apply at the same time (ken39arg #100, #101)
* Tue Aug 13 2019 Stephan Kulow <coolo@suse.com>
- updated to 2.5.7
  see /usr/share/doc/packages/perl-Mouse/Changes
  v2.5.7 2019-08-12T08:45:37Z
  - Bump Module::Build::XSUtil prereq (KnowZero #99)
* Tue Aug 14 2018 coolo@suse.com
- updated to 2.5.6
  see /usr/share/doc/packages/perl-Mouse/Changes
  v2.5.6 2018-08-13T22:47:57Z
  - Revert "Warn if accessors overwrite methods/functions" for now; it may cause crashes in perl 5.28.0 (#94)
  v2.5.5 2018-08-13T15:41:32Z
  - Warn if accessors overwrite methods/functions (ybrliiu #86, #90, #93)
  - Fix for threads and XS; use newSVpvs instead of newSVpvs_share (sergeykolychev #92)
* Sun May  6 2018 coolo@suse.com
- updated to 2.5.4
  see /usr/share/doc/packages/perl-Mouse/Changes
* Sun Feb 18 2018 coolo@suse.com
- updated to 2.5.2
  see /usr/share/doc/packages/perl-Mouse/Changes
* Tue Jan  9 2018 coolo@suse.com
- updated to 2.5.1
  see /usr/share/doc/packages/perl-Mouse/Changes
  v2.5.1 2018-01-07T14:34:19Z
  - use PERL_UNUSED_RESULT (#83)
  - Apply several minor patches, especially for packaging (#84)
* Mon Nov 27 2017 coolo@suse.com
- updated to 2.5.0
  see /usr/share/doc/packages/perl-Mouse/Changes
  v2.5.0 2017-11-26T18:38:18Z
  - Fix build under perl 5.8 (wyoung #63, autarch #76, #79)
  - Use version->declare() to declare $VERSION (neilb #55, #80)
  - Make `prove -br t` work with dot-not-in-INC perls (#81)
* Tue Jul 25 2017 coolo@suse.com
- updated to 2.4.10
  see /usr/share/doc/packages/perl-Mouse/Changes
  v2.4.10 2017-07-18T04:12:23Z
  - https://github.com/gfx/p5-Mouse/compare/v2.4.9...v2.4.10
* Thu Feb 23 2017 coolo@suse.com
- updated to 2.4.9
  see /usr/share/doc/packages/perl-Mouse/Changes
  v2.4.9 2017-02-22T01:23:31Z
  - Fix build issue on newer Perl
* Fri Feb 17 2017 coolo@suse.com
- updated to 2.4.8
  see /usr/share/doc/packages/perl-Mouse/Changes
  v2.4.8 2017-02-16T08:45:28Z
  - Fix stack collapse(#71)
* Sun Jan 15 2017 coolo@suse.com
- updated to 2.4.7
  see /usr/share/doc/packages/perl-Mouse/Changes
  v2.4.7 2017-01-14T13:46:04Z
  - Workaround for issue #64(#67)
    In some case stack is corrupted at more than 23 attributes.
    This change may makes a bit slow in that case.
* Sat Jan  7 2017 coolo@suse.com
- updated to 2.4.6
  see /usr/share/doc/packages/perl-Mouse/Changes
  v2.4.6 2017-01-06T06:51:15Z
  - Fix test for older Perls (#68)
  - Define macros for older Visual Studio compiler(#66)
* Tue Aug  4 2015 coolo@suse.com
- updated to 2.4.5
  see /usr/share/doc/packages/perl-Mouse/Changes
  v2.4.5 2015-08-03T15:57:50Z
  - Fix for older Perl(< 5.14.0) (#54)
  v2.4.4 2015-08-02T09:49:34Z
  - Fix for older Perl(< 5.22.0) (#53)
  v2.4.3 2015-08-02T07:10:09Z
  - Fix for Perl 5.22.0 or higher(#50)
* Thu Apr 16 2015 coolo@suse.com
- updated to 2.4.2
  see /usr/share/doc/packages/perl-Mouse/Changes
  2.4.2 2015-04-12T01:22:02Z
  - Fixed #40; 'use strict' not enabled when 'use 5.010' follows 'use Mouse'
  - Fixed #39; New warnings in Perl 5.21.x: redundant arguments for sprintf
  - Fixed #38; Avoid warnings introduced in Perl 5.21.x
  - Fixed #36; Excess dependency on Test::Exception::LessClever (kentnl, #37)
* Sun Nov 23 2014 coolo@suse.com
- updated to 2.4.1
  - Fix build issues (#34)
  - Fix build issues (#32)
  - Fixed #17; memory leak in applying roles to instances
  - Fixed #16 - inconsistent coercion/validation of Bool type (tokuhirom)
  - Fixed #18 (tokuhirom)
* Sat Jan  4 2014 lars@linux-schulserver.de
- update to 2.1.0:
  + Dropped 5.6.2 support
  + Migrated to Minilla
* Mon Nov 25 2013 coolo@suse.com
- updated to 2.0.0
    [BUG FIXES]
  - Merged the pull-request #13, which fixed an issue where
    the behavior of role method confliction was different
    from Moose. This change might affect your existing code
    so the major version has incremented.
    See t/030_roles/role_conflict_and_inheritance.t for details.
  - Fix for perl 5.19.4 (RT 88295)
* Fri Oct  4 2013 coolo@suse.com
- updated to 1.12
    [BUG FIXES]
  - Fix a memory leak related to triggers,
    which was introduced in 1.07 (issue#7)
* Wed Jun  5 2013 coolo@suse.com
- updated to 1.11
    [TEST FIXES]
  - Ensure Try::Tiny is bundled
  - Bundle Try::Tiny for tests
  - Bundle Test::Fatal for tests
    [FEATURES]
  - Support PUREPERL_ONLY
    See the Lancaster Consensus:
    https://github.com/sjn/toolchain-site/blob/219db464af9b2f19b04fec05547ac10180a469f3/lancaster-consensus.md#specifying-pure-perl-builds
    [BUG FIXES]
  - Make trigger pass in the old value for Moose compatibility
    (PR#6 by schwern)
    [TEST FIXES]
  - Get perlcritic tests working for PC 1.118 (PR#6 by schwern)
  - Resolve RT#84518 caused by hash randomization
    [BUG FIXES]
  - Fix a memory leak introduced by v1.04 (creaktive & aiyumi, pull-req #4)
    [FEATURES]
  - Implement $attr->default($instance) for compatibility with Moose
  - Add maybe_type() from Moose::Util::TypeConstraints (schwern)
    [IMPROVEMENT]
  - performance improvement for v5.14.0 or grater (dex4er)
* Thu Nov 17 2011 coolo@suse.com
- update to 0.97:
  - Fixes in 0.96 is broken
  - Workaround for RT#71211 (made the failing test a TODO)
  * Resolve RT#68351, tests produced deprecation warnings in 5.14
  * Resolve RT#70518, a build problem in 5.15
  * Resolve RT#70569, prototype mismatch warnings might happen in 5.8
* Thu Jul 21 2011 coolo@novell.com
- use original tar
* Tue May 17 2011 pascal.bleser@opensuse.org
- update to 0.93:
  * make sure weak attributes remain weak when cloning (Moose 2.0007)
* Sat Apr 16 2011 pascal.bleser@opensuse.org
- update to 0.92:
  * replace C++-style comments (//) with C89-style comments(/* */) (RT #67412)
* Mon Mar 14 2011 pascal.bleser@opensuse.org
- update to 0.91:
  * $type_constraint->check() accepts extra arguments for extensibility
* Tue Feb 22 2011 lars@linux-schulserver.de
- update to 0.90:
  + Fix an abuse of a private Perl API, which changed at Perl 5.13.10
  + Support the DOES() method for Mouse::Object
* Thu Jan 27 2011 pascal.bleser@opensuse.org
- update to 0.89:
  * disable foreign class warnings introduced at 0.71, which affects
    compatibility with Moose (and will re-introduce in more compatible way in
    the future)
- changes from 0.88:
  * workaround SL4A where mro.pm doesn't exist even if Perl >= 5.10.0
- changes from 0.86:
  * role application to instances cached anonymous classes in wrong way
- changes from 0.85:
  * fix an error message to be compatible with Moose's
  * fix build problems
- changes from 0.83:
  * 'Int' type constraint passed dualvars (e.g. $!) while Moose's doesn't
- changes from 0.82:
  * wrong name for a method in Mouse::Meta::TypeConstraint:
    s/is_a_subtype_of/is_a_type_of/
  * $type_constraint->type_parameter didn't return the correct value if it's a
    subtype of paramterized type constraints
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Sat Oct 30 2010 pascal.bleser@opensuse.org
- update to 0.81:
  * Bugfix: roles which attributes has no methods could affect cache invalidation
- changes from 0.80:
  * Bugfix: resolve RT #61906: a single 'accessor' did not define the method for the attribute
- changes from 0.79:
  * Bugfix: fix a mis-use of aTHX_/pTHX_ in XS
- changes from 0.78:
  * Bugfixes:
    + resolve RT #61852: parametrized type constraints didn't call their "where" clause anymore
    + Mouse::Object::DESTROY could fail to call DEMOLISHes in some cases
* Wed Sep 29 2010 pascal.bleser@opensuse.org
- update to 0.77:
  * Bugfixes:
    + fix tests failed against 5.6.2
    + combination of 'isa' and 'does' for has() sugar was incorrectly proccessed in Mouse::PurePerl
    + fix foreign class checking routines -- please update MouseX::Foreign
* Tue Sep 28 2010 pascal.bleser@opensuse.org
- update to 0.76:
  * Bugfixes:
    + workaround 5.6.problems
    + fix edge cases of handles => sub { ... }
    + avoid warnings on attribute cloning
* Mon Sep 27 2010 pascal.bleser@opensuse.org
- update to 0.75:
  * Bugfix: diamond inheritance without C3 mro cauld cause problems in Mouse::XS
- changes from 0.74:
  * Bugfixes:
    + workaround Test::Builder2 problem again
    + fix some compatibility issues on perl 5.6.2
- changes from 0.73:
  * Bugfixes:
    + resolve RT #61613
- changes from 0.72:
  * Bugfixes:
    + internal refatoring has removed a number of incompatibilities in Mouse::PurePerl
    + error messages from duck types are now compatible with Moose
- changes from 0.71:
  * Changes:
    + inheritance from non-Mouse classes now produces warnings; use MouseX::Foreign if you want this type of inheritance
    + a new module Mouse::Meta::Role::Application has been added; using Mouse without roles should consume less memory
  * Bugfixes:
    + meta class reinitialization caused by Mouse::Util::MetaRole did not work correctly
- changes from 0.70:
  * Bugfixes:
    + delegations ignored method modifiers
* Mon Sep 13 2010 lars@linux-schulserver.de
- update to 0.69:
  + Workaround a problem with Test::Builder 2.00_01, which could cause
    SEGV
  + Remove an optional depenency, Data::Util
  + Fix looks_like_number portability
  + An attribute in a subclass can now override the value of "is"
  + Remove long deprecated methods:
    _create_args(), compute_all_applicable_attributes(),
    and clone_instance()
  + Improve C++ compatibility in Mouse::XS
* Tue Aug 31 2010 pascal.bleser@opensuse.org
- update to 0.64:
  * build failure on 5.13.3
  * illegal inheritance options for clone_and_inherit_options() is now a black list, not a white list (Moose 1.09 feature)
  * remove long deprecated methods in Mouse::Meta::Attribute: clone_parent, get_parent_args, canonicalize_args, create
- changes from 0.63:
  * resolve RT#59460: Test::Requires is not a required prerequisite unless release-testing
  * add Mouse::Util::TypeConstraints::register_type_constraint() RT#59539
- changes from 0.62:
  * support MouseX::StrictConstructor
- changes from 0.61:
  * workaround the Perl_call_sv() problem again
- changes from 0.60:
  * BUILDALL is now called by Mouse::Meta::Class::new_object, rather than by Mouse::Object::new
  * fix type constraint validation messages to not include the string 'failed' twice in the same sentence
  * resolve RT #57975: the prefix "Exception caught" is no longer added to exceptions Mouse catches
- changes from 0.59:
  * improve error messages on $class->accessor()
* Mon May 10 2010 lars@linux-schulserver.de
- update to 0.58:
  + Resolve RT #57144: Fix problems in Perl_call_sv() again
  + Resolve RT#56837: Role application to instance with init_arg'd
    attributes caused problems (Sanko Robinson)
* Thu Apr 29 2010 lars@linux-schulserver.de
- update to 0.56:
  + Resolve RT#56837: Role application to instance with init_arg'd
    attributes caused problems
  + Fix a bug that traits could cause panic/SEGV on threads (gfx)
  + Resolve RT#56523: has with reader, writer, lazy and builder
    could not create a write-only accessor
  + Mouse::Meta::Class could not clone objects with "required" attrs
* Sun Mar 28 2010 lars@linux-schulserver.de
- update to 0.52:
  + Workaround Perl-RT#69939 (eval "use $module" in Perl_call_sv()
    may cause segmentation faults,
    http://rt.perl.org/rt3/Public/Bug/Display.html?id=69939)
* Mon Mar 15 2010 lars@linux-schulserver.de
- update to 0.51:
  + [BUG FIXES]
  * Mouse::Object::DESTROY could cause SEGVs
  * Attribute triggers could cause panics
  * Integers > 2**32 ware not groked as Int
  * Incorrect types, e.g. "Array[Int", was accepted
  * Metaclass compatibility was sometimes ignored
  + [MOOSE COMPATIBILITY]
  * before/around/after accept regular expressions
  * has() becomes strict
  * the global destruction flag is passed to DEMOLISH methods
  * Delegations can be curried
  * Built-in type constraints have the same hierarchy as Moose's
* Sat Feb 20 2010 lars@linux-schulserver.de
- update to 0.50:
  * Mouse::Tiny
  - Allow "use Mouse::Tiny VERSION" with a patch contributed by
    chocolateboy, RT #54383 (gfx)
  * Mouse::Util::MetaRole
  - Add Mouse::Util::MetaRole::apply_metaroles
    to catch up the latest Moose API for metaroles (gfx)
  * MouseAccessor.xs
  - Fix RT #54203 that writers might return undef in setting values
    reported by chocolateboy (gfx)
  * MouseTypeConstraints.xs
  - Fix magic handling in type constraints reported by sunnavy (gfx)
  * Makefile.PL
  - Shipped with M::I::XSUtil 0.21 (gfx)
  - Fix an issue that gcc 4.0 don't support -Wc++-compat (gfx)
  * Mouse
  - Add a caveat on XS callbacks to the pod (gfx)
  * Mouse::Meta::Attribute
  - Add support for code references for handles
    patched by Frank Cuny (gfx)
  * Mouse::Util::TypeConstraints
  - Fix Str and ScalarRef for typeglobs, lvalues, and etc. (gfx)
  * Moose.pm
  - Add Moose::Util::TypeConstraints exports to allow easier testing
    of TypeConsraints from the command line (gfx)
- BuildRequire perl-Test-Excpetion to run make check successfully
* Sat Dec 26 2009 lars@linux-schulserver.de
- initial version 0.4501
